@@ -389,6 +389,7 @@ class DataFrameSchematizer:
         3. default values are applied
         4. final validation
         """
+        _df_debug = df.copy()
         schema = self.build()
         validator = jsonschema.Draft7Validator(schema)
         # =====================================================================
@@ -456,21 +457,25 @@ class DataFrameSchematizer:
             k: schema["properties"][k]["items"].get("default")
             for k, v in schema["properties"].items()
         }
+        padded_columns = [colname for colname, value in _fillnas.items() if value == "_pad_"]
         fillnas = {
             k: v for k, v in _fillnas.items() if k in df.columns and v is not None
         }
         if fillnas:
             df = df.fillna(value=fillnas, downcast="infer")
+        if padded_columns:
+            df = df.replace({"_pad_": np.nan})
+            df[padded_columns] = df[padded_columns].fillna(method="pad")
+            # df = df.fillna(method="pad", 
         # =====================================================================
         # build dummy columns if required by the multiple-columns uniqueness
         # =====================================================================
         dummies = []
         for uniqueness_tag, columns in self.uniqueness_sets.items():
-            _df = df[columns].astype(str)
+            _df = df[columns].fillna(method="ffill").astype(str)
             dummy_col = UNIQUENESS_SEP.join(columns)
             dummies.append(dummy_col)  # to delete them later on
             df[dummy_col] = _df.apply(UNIQUENESS_SEP.join, axis=1)
-
         # =====================================================================
         # second validation
         # =====================================================================
