@@ -714,10 +714,70 @@ def test_IVData_08_multi_cols_uniqueness(datadir):
     )
     rep = data_si.validate()
     assert rep == {
+        "WithPadding_failing": {
+            ("rail_tag & x_loc & block_label", "?"): [
+                "value " "{'RBL12 & " "3800.0 & " "s1'} is " "not " "unique"
+            ]
+        },
         "asm_failing": {
             ("another", "?"): ["value {1.0} is not unique"],
             ("rail_tag & x_loc & block_label", "?"): [
-                "value {'RBL11 & 3500 & RECARO1'} is not unique"
+                "value {'RBL11 & " "3500 & RECARO1'} " "is not unique"
             ],
-        }
+        },
     }
+    df = data_si.get("WithPadding_ok")
+    expected_df = pd.DataFrame(
+        {
+            1: {
+                "another": 1.0,
+                "block_label": "RECARO1",
+                "block_ref_point_id": 2.0,
+                "optional": 2.0,
+                "rail_tag": "RBL11",
+                "x_loc": 3500.0,
+            },
+            2: {
+                "another": 2.0,
+                "block_label": "RECARO1",
+                "block_ref_point_id": 2.0,
+                "optional": 3.0,
+                "rail_tag": "RBL11",
+                "x_loc": 8500.0,
+            },
+            3: {
+                "another": 3.0,
+                "block_label": "s1",
+                "block_ref_point_id": 2.0,
+                "optional": np.nan,
+                "rail_tag": "RBL12",
+                "x_loc": 3800.0,
+            },
+            4: {
+                "another": 4.0,
+                "block_label": "s2",
+                "block_ref_point_id": 2.0,
+                "optional": 0.0,
+                "rail_tag": "RBL12",
+                "x_loc": 3800.0,
+            },
+            5: {
+                "another": 5.0,
+                "block_label": "s1",
+                "block_ref_point_id": 2.0,
+                "optional": np.nan,
+                "rail_tag": "RBL12",
+                "x_loc": 8500.0,
+            },
+            6: {
+                "another": 6.0,
+                "block_label": "s1",
+                "block_ref_point_id": 2.0,
+                "optional": np.nan,
+                "rail_tag": "RBL12",
+                "x_loc": 7900.0,
+            },
+        }
+    ).T
+    expected_df = expected_df[[c for c in df]]
+    assert pd.testing.assert_frame_equal(df, expected_df, check_dtype=False) is None
